HashWriter

Struct HashWriter 

pub struct HashWriter<'a, H: DeterministicHasher + ?Sized> { /* private fields */ }
A Writer that sinks bytes directly into a [DeterministicHasher] instead of a buffer.

This allows encoding values directly to a hash without intermediate buffer allocation.

Implementations

Source

impl<'a, H: DeterministicHasher + ?Sized> HashWriter<'a, H>

pub fn new(hasher: &'a mut H) -> Self

Creates a new HashWriter that writes to the given hasher.