pub struct HashWriter<'a, H: DeterministicHasher + ?Sized> { /* private fields */ }Expand description
A Writer that sinks bytes directly into a [DeterministicHasher] instead of a buffer.
This allows encoding values directly to a hash without intermediate buffer allocation.
Implementations